:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _thirdparty:

Third Party Applications
========================

A list of 3rd-party applications compatible with |grappelli|.


Django FileBrowser
------------------

No additional setup is needed when installing the `Django FileBrowser <https://github.com/sehmaschine/django-filebrowser>`_ with Grappelli.

Django Reversion
----------------

.. versionadded:: 2.4.0

|grappelli| includes all necessary templates for `Django Reversion <https://github.com/etianen/django-reversion/>`_.

.. note::

	``grappelli`` needs to be before ``reversion`` within ``INSTALLED_APPS``.

Django Smuggler
---------------

.. versionadded:: 2.4.5

|grappelli| includes all necessary templates for `Django Smuggler <https://github.com/etianen/django-reversion/>`_.

.. note::

	``grappelli`` needs to be before ``smuggler`` within ``INSTALLED_APPS``.

Django Constance
----------------

.. versionadded:: 2.4.6

|grappelli| includes the necessary template for `Django Constance <https://github.com/comoga/django-constance/>`_.

.. note::

	``grappelli`` needs to be before ``constance`` within ``INSTALLED_APPS``.